Documentation
¶
Overview ¶
SPDX-License-Identifier: Apache-2.0
SPDX-License-Identifier: Apache-2.0
Index ¶
- func CalculateSHA256(filePath string) (string, error)
- func CompressXZ(src, dst string) error
- func CompressXZWithProgress(src, dst string, progressCallback func(float64)) error
- func DecompressXZ(src, dst string) error
- func DecompressXZWithProgress(src, dst string, progressCallback func(float64)) error
- func ExtractTarGz(src, dstDir string) error
- func ExtractTarXz(src, dstDir string) error
- func ExtractTarXzWithProgress(src, dstDir string, progressCallback func(float64)) error
- func ParseSHA256SUMSFile(path string) (map[string]string, error)
- func VerifySHA256File(filePath, checksumsPath string) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateSHA256 ¶
CalculateSHA256 calculates the SHA256 hash of a file
func CompressXZ ¶
CompressXZ compresses a file using xz compression
func CompressXZWithProgress ¶
CompressXZWithProgress compresses a file with progress tracking
func DecompressXZ ¶
DecompressXZ decompresses an xz file to a destination path
func DecompressXZWithProgress ¶
DecompressXZWithProgress decompresses an xz file with progress tracking
func ExtractTarGz ¶
ExtractTarGz extracts a tar.gz archive to a destination directory
func ExtractTarXz ¶
ExtractTarXz extracts a tar.xz archive to a destination directory
func ExtractTarXzWithProgress ¶
ExtractTarXzWithProgress extracts a tar.xz archive with progress tracking
func ParseSHA256SUMSFile ¶
ParseSHA256SUMSFile parses a SHA256SUMS file and returns a map of filename -> hash
func VerifySHA256File ¶
VerifySHA256File verifies a file against a SHA256SUMS file
Types ¶
This section is empty.